==> kubernetes-model-1.0.30-sources.jar: annotations/io/fabric8/openshift/api/model/RecreateDeploymentStrategyParamsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class RecreateDeploymentStrategyParamsFluentImpl<T extends RecreateDeploymentStrategyParamsFluent<T>> extends BaseFluent<T> implements RecreateDeploymentStrategyParamsFluent<T>{

     VisitableBuilder<LifecycleHook, ?> post;     VisitableBuilder<LifecycleHook, ?> pre;     Map<String, Object> additionalProperties = new HashMap();

    public LifecycleHook getPost(){
    return this.post!=null?this.post.build():null;
    }
    public T withPost( LifecycleHook post){
    if (post!=null){ this.post= new LifecycleHookBuilder(post); _visitables.add(this.post);} return (T) this;
    }
    public PostNested<T> withNewPost(){
    return new PostNestedImpl<T>();
    }
    public PostNested<T> withNewPostLike( LifecycleHook item){
    return new PostNestedImpl<T>(item);
    }
    public PostNested<T> editPost(){
    return withNewPostLike(getPost());
    }
    public LifecycleHook getPre(){
    return this.pre!=null?this.pre.build():null;
    }
    public T withPre( LifecycleHook pre){
    if (pre!=null){ this.pre= new LifecycleHookBuilder(pre); _visitables.add(this.pre);} return (T) this;
    }
    public PreNested<T> withNewPre(){
    return new PreNestedImpl<T>();
    }
    public PreNested<T> withNewPreLike( LifecycleHook item){
    return new PreNestedImpl<T>(item);
    }
    public PreNested<T> editPre(){
    return withNewPreLike(getPre());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
RecreateDeploymentStrategyParamsFluentImpl that = (RecreateDeploymentStrategyParamsFluentImpl) o;
if (post != null ? !post.equals(that.post) :that.post != null) return false;
if (pre != null ? !pre.equals(that.pre) :that.pre != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class PostNestedImpl<N> extends LifecycleHookFluentImpl<PostNested<N>> implements PostNested<N>{

        private final LifecycleHookBuilder builder;
    
             PostNestedImpl (){
        this.builder = new LifecycleHookBuilder(this);
        }
             PostNestedImpl ( LifecycleHook item){
        this.builder = new LifecycleHookBuilder(this, item);
        }
    
            public N endPost(){
            return and();
        }
            public N and(){
            return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withPost(builder.build());
        }
    
}
    public class PreNestedImpl<N> extends LifecycleHookFluentImpl<PreNested<N>> implements PreNested<N>{

        private final LifecycleHookBuilder builder;
    
             PreNestedImpl (){
        this.builder = new LifecycleHookBuilder(this);
        }
             PreNestedImpl ( LifecycleHook item){
        this.builder = new LifecycleHookBuilder(this, item);
        }
    
            public N and(){
            return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withPre(builder.build());
        }
            public N endPre(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.42-sources.jar: annotations/io/fabric8/openshift/api/model/RecreateDeploymentStrategyParamsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class RecreateDeploymentStrategyParamsFluentImpl<T extends RecreateDeploymentStrategyParamsFluent<T>> extends BaseFluent<T> implements RecreateDeploymentStrategyParamsFluent<T>{

     VisitableBuilder<LifecycleHook, ?> mid;     VisitableBuilder<LifecycleHook, ?> post;     VisitableBuilder<LifecycleHook, ?> pre;     Long timeoutSeconds;     Map<String, Object> additionalProperties = new HashMap();
public RecreateDeploymentStrategyParamsFluentImpl(){
    
}
public RecreateDeploymentStrategyParamsFluentImpl( RecreateDeploymentStrategyParams instance ){
    this.withMid(instance.getMid()); this.withPost(instance.getPost()); this.withPre(instance.getPre()); this.withTimeoutSeconds(instance.getTimeoutSeconds()); 
}

    public LifecycleHook getMid(){
    return this.mid!=null?this.mid.build():null;
    }
    public T withMid( LifecycleHook mid){
    if (mid!=null){ this.mid= new LifecycleHookBuilder(mid); _visitables.add(this.mid);} return (T) this;
    }
    public MidNested<T> withNewMid(){
    return new MidNestedImpl<T>();
    }
    public MidNested<T> withNewMidLike( LifecycleHook item){
    return new MidNestedImpl<T>(item);
    }
    public MidNested<T> editMid(){
    return withNewMidLike(getMid());
    }
    public LifecycleHook getPost(){
    return this.post!=null?this.post.build():null;
    }
    public T withPost( LifecycleHook post){
    if (post!=null){ this.post= new LifecycleHookBuilder(post); _visitables.add(this.post);} return (T) this;
    }
    public PostNested<T> withNewPost(){
    return new PostNestedImpl<T>();
    }
    public PostNested<T> withNewPostLike( LifecycleHook item){
    return new PostNestedImpl<T>(item);
    }
    public PostNested<T> editPost(){
    return withNewPostLike(getPost());
    }
    public LifecycleHook getPre(){
    return this.pre!=null?this.pre.build():null;
    }
    public T withPre( LifecycleHook pre){
    if (pre!=null){ this.pre= new LifecycleHookBuilder(pre); _visitables.add(this.pre);} return (T) this;
    }
    public PreNested<T> withNewPre(){
    return new PreNestedImpl<T>();
    }
    public PreNested<T> withNewPreLike( LifecycleHook item){
    return new PreNestedImpl<T>(item);
    }
    public PreNested<T> editPre(){
    return withNewPreLike(getPre());
    }
    public Long getTimeoutSeconds(){
    return this.timeoutSeconds;
    }
    public T withTimeoutSeconds( Long timeoutSeconds){
    this.timeoutSeconds=timeoutSeconds; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
RecreateDeploymentStrategyParamsFluentImpl that = (RecreateDeploymentStrategyParamsFluentImpl) o;
if (mid != null ? !mid.equals(that.mid) :that.mid != null) return false;
if (post != null ? !post.equals(that.post) :that.post != null) return false;
if (pre != null ? !pre.equals(that.pre) :that.pre != null) return false;
if (timeoutSeconds != null ? !timeoutSeconds.equals(that.timeoutSeconds) :that.timeoutSeconds != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MidNestedImpl<N> extends LifecycleHookFluentImpl<MidNested<N>> implements MidNested<N>{

        private final LifecycleHookBuilder builder;
    
             MidNestedImpl ( LifecycleHook item){
        this.builder = new LifecycleHookBuilder(this, item);
        }
             MidNestedImpl (){
        this.builder = new LifecycleHookBuilder(this);
        }
    
            public N endMid(){
            return and();
        }
            public N and(){
            return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withMid(builder.build());
        }
    
}
    public class PostNestedImpl<N> extends LifecycleHookFluentImpl<PostNested<N>> implements PostNested<N>{

        private final LifecycleHookBuilder builder;
    
             PostNestedImpl (){
        this.builder = new LifecycleHookBuilder(this);
        }
             PostNestedImpl ( LifecycleHook item){
        this.builder = new LifecycleHookBuilder(this, item);
        }
    
            public N endPost(){
            return and();
        }
            public N and(){
            return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withPost(builder.build());
        }
    
}
    public class PreNestedImpl<N> extends LifecycleHookFluentImpl<PreNested<N>> implements PreNested<N>{

        private final LifecycleHookBuilder builder;
    
             PreNestedImpl (){
        this.builder = new LifecycleHookBuilder(this);
        }
             PreNestedImpl ( LifecycleHook item){
        this.builder = new LifecycleHookBuilder(this, item);
        }
    
            public N and(){
            return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withPre(builder.build());
        }
            public N endPre(){
            return and();
        }
    
}


}
